@@ -2,6 +2,7 @@
 #define __DYNAMIC_ME__
 
 #include<stdio.h>
+#include <pthread.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -10,6 +11,11 @@ extern "C" {
 #include "../../../include/num_out.h"
 #include "../../../include/nType.h"
 
+extern pthread_mutex_t* dynamic_cs_mutex;
+extern int destroy_dynamic_cs_mutex(void);
+extern int init_dynamic_cs_mutex(void);
+
+
 typedef struct numout
 {
   void * handle;
@@ -48,8 +54,8 @@ extern int  checkMtime(char * fname);
 extern int  checkWorkPlace(void);
 extern int getDynamicVP(void);
 extern int setModel(char * modelDisp , int nModel);
-extern int assignVal(const char * name, double val);
-extern int assignValW(const char * name, double val);
+extern int assignVal(char * name, double val);
+extern int assignValW(char * name, double val);
 extern int findVal(char * name, double*val);
 extern double findValW(char * name);
 extern int readVar(char *fname);
@@ -67,7 +73,7 @@ extern void printTxtList(txtList L, FILE *f);
 extern lVert* getVertex(char*n1,char*n2,char*n3,char*n4);
 int  getNumCoeff(lVert*vv, double * coeff);
 /*===========================================================*/
-typedef struct{ double width; txtList pdList[2]; int status;}  decayTableStr;
+typedef struct{ double width; txtList pdList[2]; int status; int pref;}  decayTableStr;
 
 extern double   (*sqme)(int nsub,double GG,REAL *pvect,REAL*cb_coeff, int * err_code);
 extern REAL   decayPcm(REAL am0,  REAL  am1,  REAL  am2);
@@ -84,6 +90,7 @@ extern int      pname2lib(char*pname, char * libname);
 extern double   decay2Info(char * pname, FILE* f);
 extern int      useSLHAwidth;
 extern double   pWidth(char *name, txtList * LL);
+extern int      pWidthPref(char *name, int pref);
 extern double   pWidthCC(numout*cc,int*err);
 extern double   aWidth(char *name);
 extern double   findBr(txtList L, char * pattern);
