@@ -137,7 +137,7 @@ int setModel(char * modelDisp , int nModel )
 }
 
 
-int assignVal(const char * name, double val)
+int assignVal(char * name, double val)
 {
   int i; 
   for(i=0;i<nModelVars;i++)
@@ -148,7 +148,7 @@ int assignVal(const char * name, double val)
   return 2;
 }
 
-int assignValW(const char*name, double  val)
+int assignValW(char*name, double  val)
 {
   if(assignVal(name,val)) { printf(" %s not found\n",  name); return 1;}
   else return 0;
