@@ -1,4 +1,4 @@
-int FError;
+//int FError;
 
 #include<stdio.h>
 #include<stdlib.h>
