@@ -158,13 +158,13 @@ static void* vegas_cycle(void * par_)
       fb  = 0;
       f2b = 0;
       for(i = 0; i<npg; i++) 
-      {   double w;
+      {  
+        double w;
           if(nCore)pthread_mutex_lock(&drandXX_key);  
             for(k=0;k<dim;k++)  xlocal[k]= drandXX();    
           if(nCore)pthread_mutex_unlock(&drandXX_key);            
           Local2Global(par->vegPtr ,Kg_, Ng, xlocal,x, &w, ia);
           f = par->vegPtr->fxn(x,w)*w;
-
           if(!isfinite(f)) 
           { if(nCore)pthread_mutex_lock(&(par->key));
             par->end=-1;
