@@ -201,7 +201,7 @@ L10:{  char strmen[]="\030"
            if(correctDouble(3,15,"Enter new value ",&alphaMZ,1)) returnCode=1;
            if(alphaMZ>0 && alphaMZ<0.3) returnCode=1; else  
            { alphaMZ=alphaMZ_old;
-              messanykey(5,15,"Your input is out of alphaMZ range");
+              messanykeyErr(5,15,"Your input is out of alphaMZ range");
            }
          }
          break;
@@ -210,7 +210,7 @@ L10:{  char strmen[]="\030"
            if(correctInt(3,15,"Enter new value ",&alphaNF,1))
            {
               if(alphaNF<=6 && alphaNF>=3) returnCode=1;
-              else { messanykey(5,15,"NF out of range"); alphaNF=NF_old;}
+              else { messanykeyErr(5,15,"NF out of range"); alphaNF=NF_old;}
            }   
          }
          break;
