@@ -105,8 +105,7 @@ int fillCutArray(void)
   errorExit:
   { char buff[300];
     sprintf(buff," Error in Cut table line %d \n%s\n%s",lineNum,fieldName,errorText);
-    
-    if(blind) { printf("%s\n",buff); sortie(150);} else messanykey(2,10,buff);
+    messanykeyErr(2,10,buff);
     return 1;
   }     
 }
