@@ -226,8 +226,42 @@ static int  in_setting(void)
   int i;
   int returnCode=0;
 
-  if(nin_int == 1) return returnCode;
+  if(nin_int == 1)
+  {
+    for(;;)                                                                                          
+    {
+      char strmen[] = "*"
+      " Incomming  particle momentum[GeV] = PPP1      "
+      " Incomming  particle helicity (not implemented)";
 
+      Pcm=va_int[0];
+
+      strmen[0]=strlen(strmen)/2;
+      
+      improveStr(strmen,"PPP1","%-10.4G",inP1);
+
+/*
+      if(is_polarized(1,Nsub))
+      improveStr(strmen,"FirstPol", "Helicity of  first particle   %.3G",(double)Helicity[0]);
+      else improveStr(strmen,"FirstPol", "First  particle unpolarized");
+*/      
+
+      f3_key[4]=f7_prog;   f3_mess[4]="Plot";
+      menu1(25,7,"",strmen,"n_in_*",&pscr,&mode);
+      f3_key[4]= f7_tmp;  f3_mess[4]=f7_mess_tmp;
+
+      switch(mode)
+      { case 0:   
+           pinf_int(Nsub,1,mass,NULL);
+           return returnCode;
+        case 1: 
+           correctDouble(50,12,"Enter new value ",&inP1,1);
+           returnCode=returnCode|1;
+            break;
+      }      
+    }
+  }
+  
   for(i=0;i<2;i++) 
   if(sf_num[i])mass[i]=sf_mass[i];else pinf_int(Nsub,i+1,mass+i,NULL);
    
