@@ -134,6 +134,9 @@ double calcPhysVal(char key,char * lv,double*V)
         case 'E':
             while(lv[i]!=0)   s += V[  (lv[i++]<<2)  -4];
             return s;
+        case 'L':
+            while(lv[i]!=0)  { pinf_int(Nsub, lv[i], &mp, NULL);  s += V[  (lv[i++]<<2)  -4]-mp ;  }
+            return log10(s);    
 
         case 'T':
             {  i=0; 
@@ -169,7 +172,7 @@ double calcPhysVal(char key,char * lv,double*V)
                do for(j=0;j<4;j++) pp[j] += V[4*(lv[i]-1)+j]; while(lv[++i]);
                mp = sqrt(pp[1]*pp[1]+pp[2]*pp[2]+pp[3]*pp[3]);
                return  log(( mp+pp[3])/(mp-pp[3]))/2;
-        case 'W':
+         case 'W':
             {  double E=0;
                double *q; 
                for(;lv[i];i++) 
@@ -181,7 +184,7 @@ double calcPhysVal(char key,char * lv,double*V)
                }
                return sqrt(E*E - pp[1]*pp[1] - pp[2]*pp[2] );  
             }                                                                  
-        case 'U': return usrfun(lv,nin_int,nout_int,V,p_names,p_codes);
+         case 'U': return usrfun(lv,nin_int,nout_int,V,p_names,p_codes);
     }
     return 0;
 }
@@ -260,7 +263,7 @@ int  checkPhysValN(char * name, char * key, physValRec **pLists)
 
   
 
-  if(!strchr("ACDEFJKMPTUYNWZ",*key)) {sprintf(errorText,"wrong key '%c'",*key);  return 0;}
+  if(!strchr("ACDEFJKLMPTUYNWZ",*key)) {sprintf(errorText,"wrong key '%c'",*key);  return 0;}
   chB++;  
 
   if(*key=='E' && nin_int==2 && (strcmp(chB,"1")==0 ||strcmp(chB,"2")==0)) 
