@@ -563,8 +563,8 @@ int imkmom(double P1, double P2)
     } else 
     {   REAL m1=pm[0];
 
-//        rapidity=Log((P1+Sqrt(P1*P1+m1*m1))/m1 ) ;
-        rapidity=0;  
+        rapidity=Log((P1+Sqrt(P1*P1+m1*m1))/m1 ) ;
+//        rapidity=0;  
     }
     for(i = 0; i < nout1; ++i) 
     {
