@@ -135,8 +135,11 @@ static int r_mdl__(FILE * mode)
 
   for(;;)
   { if(2!= fscanf(mode,"%s = %lf",name1,&val)) break;
-    for(i=0;i< nModelVars;i++)if(strcmp(name1,varNames[i])==0)
-    { varValues[i] = val; break;}
+    for(i=0;i< nModelVars;i++)if(strcmp(name1,varNames[i])==0) { varValues[i] = val; break;}
+    if(i==nModelVars && strcmp(name1,"GG")!=0  )
+    { char mess[100]; sprintf(mess,"session.dat contains variable '%s', which is absent in the model\n",name1);
+      messanykeyErr(10,10,mess);
+    }
   }  
   return 0;
 } 
@@ -248,7 +251,7 @@ int w_sess__(FILE *mode_)
       sprintf(fname,"%saux/session.dat",outputDir);
       mode=fopen(fname,"w");
       if(mode) {writeParagraphs(mode,9,wrt_array+2); fclose(mode);}
-   } else   writeParagraphs(mode,10,wrt_array);
+   } else   writeParagraphs(mode,11,wrt_array);
 
    return 0;
 }    
