@@ -96,8 +96,8 @@ static double calcwidth12(void)
       if(first)
       { 
         if(EffQmass&&Q) setQforParticle(Q,inParticle); 
-        if(calcMainFunc()>0) {  messanykey(15,15,"Can not  calculate constraints"); return 0;}
-        if(calcFunc_int()>0) {  messanykey(15,15,"Can not  calculate constraints"); return 0;} 
+        if(calcMainFunc()>0) {  messanykeyErr(15,15,"Can not  calculate constraints"); return 0;}
+        if(calcFunc_int()>0) {  messanykeyErr(15,15,"Can not  calculate constraints"); return 0;} 
         if(Q) GG=sqrt(4*M_PI*alpha_2(*Q)); else GG=sqrt(4*M_PI*alpha_2(m1));
         first=0;
       }  
