@@ -867,9 +867,9 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
        { fprintf(outfile,"c=sqrt(x%d[1]/x%d[0])\n",k,k);
          fprintf(outfile,"errL=x%d*(1-1/c)\n",k);
          fprintf(outfile,"errR=x%d*(c-1)\n",k); 
-         fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=[errL,errR], fmt=None,label='%s')\n",k,k,Dim[k],k,Dim[k],Y[k]);
+         fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=[errL,errR], fmt='',label='%s')\n",k,k,Dim[k],k,Dim[k],Y[k]);
        }
-       else     fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=%e, fmt=None,label='%s')\n",k,k,Dim[k],k,Dim[k],0.45*(xMax-xMin)/Dim[k],Y[k]);
+       else     fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=%e, fmt='',label='%s')\n",k,k,Dim[k],k,Dim[k],0.45*(xMax-xMin)/Dim[k],Y[k]);
      }else  if(type[k]=='s') // interpolation  
      { 
        if(logY) 
@@ -1346,7 +1346,8 @@ int  plot_Nar( char*file, char*  title, char*xName, double xMin, double xMax,  i
    ymax=grafminmax.ymax;
    
    logX=xScale;
-   logY=(ymin >0 && grafminmax.ymax/grafminmax.ymin >100);   
+   logY=(ymin >0 && grafminmax.ymax/grafminmax.ymin >100 );   
+   if(logY && grafminmax.ymin < grafminmax.ymax*1E-100) logY=0; 
    k = 0;      
 REDRAW:
    nCol0=maxCol();
@@ -1375,7 +1376,7 @@ REDRAW:
      y=yPhys();
 //     if(y<=yMin||y>=yMax) continue;
      int  w=2+log10(fabs((xMax+xMin)/(xMax-xMin) ));    
-     goto_xy(1,maxRow()-1); scrcolor(Blue,bkcolor); print("Mouse: X=%.*E ",w,x);
+     goto_xy(1,maxRow()-1); scrcolor(Blue,bkcolor); print("Mouse: %s=%.*E ",xName,w,x);
      if(mouseXY) print(" Y=%.2E ",yPhys()); else     
      { 
        print(" Func =");
@@ -1526,8 +1527,8 @@ contin:
                 logY = 0;
              }
                  
-             if(logY && (grafminmax.ymin <=0)) grafminmax.ymin=grafminmax.ymax*1E-4;
-             
+             if(logY && (grafminmax.ymin <=0)) grafminmax.ymin=grafminmax.ymax*1E-10;
+             if(logY && (grafminmax.ymin <= grafminmax.ymax*1E-100 )) grafminmax.ymin=grafminmax.ymax*1E-100;
               
              if(logY &&  grafminmax.ymax/grafminmax.ymin <=10 ) grafminmax.ymin=grafminmax.ymax/10.;
                             
