@@ -64,6 +64,7 @@ static void*  act_num(char* ch,int n, void**args)
                  else if(!strcmp(ch,"atan")) p1=atan(p1);
                  else if(!strcmp(ch,"exp"))  p1=exp(p1);
                  else if(!strcmp(ch,"log"))  p1=log(p1);
+                 else if(!strcmp(ch,"log10"))  p1=log10(p1);
                  else if(!strcmp(ch,"fabs")) p1=fabs(p1);
                  else isAble =0;
                    break;
@@ -106,7 +107,7 @@ int calcExpression(char *s,int(*nameToDouble)(char *,double *), double *p)
   if(rderrcode==0 && !isAble) rderrcode=unknownfunction; 
  
   if(!rderrcode) *p=*r;
-  if(!rderrcode && !finite(*r)) rderrcode=cannotevaluate;
+  if(!rderrcode && !isfinite(*r)) rderrcode=cannotevaluate;
  
   release_(&heapbeg); 
   return rderrcode;
