@@ -25,19 +25,21 @@ double sf_be[2]={0,0};
 static int nnan[2]={0,0};
 
 static int* allInP(int i1)
-{ static int * plist=NULL;
+{ static int * plist[2]={NULL,NULL};
+  int i=i1-1;
+  if(plist[i]) return plist[i];
   int k,l;
-  plist=realloc(plist,(nprc_int+1)*sizeof(int));
+  plist[i]=realloc(plist[i],(nprc_int+1)*sizeof(int));
   l=0; 
   for(k=0;k<nprc_int;k++)
   { int N;
     int j;
     pinf_int(k+1,i1,NULL,&N);
-    for(j=0;j<l;j++) if(N==plist[j]) break;
-    if(j==l) plist[l++]=N;
+    for(j=0;j<l;j++) if(N==plist[i][j]) break;
+    if(j==l) plist[i][l++]=N;
   } 
-  plist[l]=0;
-  return plist;  
+  plist[i][l]=0;
+  return plist[i];  
 }
 
 static struct 
