@@ -28,6 +28,7 @@
 #include "sos.h"
 #include "sets.h"
 #include "symb_tot.h"
+#include "read_mdl.h"
 
 /*#define STRACE */
 #ifdef STRACE
@@ -184,8 +185,6 @@ static int  findSpinLength(void)
 /*   spinLength =1+ (spinLength +1)/sizeof(long);*/
 }
 
-
-
 static void  propagatorsfirstreading(void)
 {  int  ninout, v, n, l;
 
@@ -228,6 +227,9 @@ static void  propagatorsfirstreading(void)
 }
 
 
+
+
+
 static void  addinoutmasses(void)
 {  int  n, m;
    char * massname;
@@ -766,8 +768,6 @@ static void  formBlocks(void)
            sprintf(txt,"m%d.m%d -N_p1p2_*(m%d.p%d*m%d.p%d+m%d.p%d*m%d.p%d  - i*Helicity%d*eps(p%d,p%d,m%d,m%d))",
                         m1,  m2,           m1,  P,m2,Paux,m1, Paux,m2,P,                P,       P,Paux,m1,m2);
            if(strcmp(inoutmasses[Paux-1],"0")) sprintf(txt+strlen(txt),"+N_p1p2_^2*m%d.p%d*m%d.p%d*%s^2",m1,P,m2,P,inoutmasses[Paux-1]); 
-                           
-//           printf("txt=%s\n", txt);                
                                                       
            m=symb_read(txt);
 
@@ -1471,9 +1471,9 @@ int writeVertexCode(char*pathToModels,int Model,int N,char**field_txt,char *labe
        int Nterm=symb_expand(v, &txt, &exp);
 
     int nvars=vert_code(vardef);
-    writeF(" double R=(");writepolyC(tcN.expr.p);writeF(")/(");writepolyC(tcD.expr.p); writeF(");\n");
+    writeF(" double R=(double)(");writepolyC(tcN.expr.p);writeF(")/(double)(");writepolyC(tcD.expr.p); writeF(");\n");
         
-    for(int i=0;i<Nterm;i++) { writeF(" coeff_out[%d]=R*(",i); writepolyC(exp[i]); writeF(");\n"); }     
+    for(int i=0;i<Nterm;i++) { writeF(" coeff_out[%d]=R*(",i); writepolyC(exp[i]); writeF(");\n"); }  
     writeF(" return 0;\n}\n"); 
 
     writeF(" static char *SymbVert[%d]={",Nterm);
