@@ -10,6 +10,7 @@
 
 #include"num1.h"
 
+int useSLHAwidth=1;
 
 static void wrongParam(int N)
 { 
@@ -179,13 +180,12 @@ int  main(int argc,char** argv)
     fprintf(stdout,"\n");
       
 
-   fprintf(stdout,"#type 1  %%1d-histogram\n");
+//   fprintf(stdout,"#type 1  %%1d-histogram\n");
    fprintf(stdout,"#xName %s\n",argv[1]);
    fprintf(stdout,"#xMin %E\n",minX);
    fprintf(stdout,"#xMax %E\n",maxX);
    fprintf(stdout,"#xDim %d\n",nbin);
    fprintf(stdout,"#yName %s {h}\n",yname);
-   fprintf(stdout,"#dataList  {h}\n");
    fprintf(stdout,"#lost_momenta_max/Etot %.1E %.1E %.1E %.1E ( line=%d)\n",pmiss[0],pmiss[1],pmiss[2],pmiss[3],Nmiss);
   }
   for(i=0;i<nbin;i++) fprintf(stdout,"%-12E  %-12E\n",hist[i],dhist[i]);
